"use strict";

exports.__esModule = true;
exports.jobsV2Reducer = void 0;

const jobsV2Reducer = (state = {
  incomplete: new Map(),
  complete: new Map()
}, action) => {
  switch (action.type) {
    case `CREATE_JOB_V2`:
      {
        const {
          job,
          plugin
        } = action.payload;
        state.incomplete.set(job.contentDigest, {
          job,
          plugin
        });
        return state;
      }

    case `END_JOB_V2`:
      {
        const {
          jobContentDigest,
          result
        } = action.payload;
        const {
          job
        } = state.incomplete.get(jobContentDigest);

        if (!job) {
          throw new Error(`If you encounter this error, it's probably a Gatsby internal bug. Please open an issue reporting us this.`);
        }

        state.incomplete.delete(job.contentDigest); // inputPaths is used to make sure the job is not stale

        state.complete.set(job.contentDigest, {
          result,
          inputPaths: job.inputPaths
        });
        return state;
      }

    case `REMOVE_STALE_JOB_V2`:
      {
        const {
          contentDigest
        } = action.payload;
        state.incomplete.delete(contentDigest);
        state.complete.delete(contentDigest);
        return state;
      }
  }

  return state;
};

exports.jobsV2Reducer = jobsV2Reducer;
//# sourceMappingURL=jobsv2.js.map