"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.runPageQueries = runPageQueries;

var _query = require("../query");

var _reporter = _interopRequireDefault(require("gatsby-cli/lib/reporter"));

var _assertStore = require("../utils/assert-store");

async function runPageQueries({
  parentSpan,
  queryIds,
  store,
  program,
  graphqlRunner
}) {
  (0, _assertStore.assertStore)(store);

  if (!queryIds) {
    return;
  }

  const {
    pageQueryIds
  } = queryIds;
  const state = store.getState();
  const pageQueryIdsCount = pageQueryIds.filter(id => state.pages.has(id)).length;

  if (!pageQueryIdsCount) {
    return;
  }

  const activity = _reporter.default.createProgress(`run page queries`, pageQueryIdsCount, 0, {
    id: `page-query-running`,
    parentSpan
  });

  activity.start();
  await (0, _query.processPageQueries)(pageQueryIds, {
    state,
    activity,
    graphqlRunner,
    graphqlTracing: program === null || program === void 0 ? void 0 : program.graphqlTracing
  });
  activity.done();
}
//# sourceMappingURL=run-page-queries.js.map